@@ -1,10 +1,13 @@
-import re, sys
+import re
+import sys
+
 cookie_re = re.compile(b"coding[:=]\s*([-\w.]+)")
 if sys.version_info[0] == 2:
     default_encoding = 'ascii'
 else:
     default_encoding = 'utf-8'
 
+
 def guess_encoding(fp):
     for i in range(2):
         ln = fp.readline()
@@ -15,9 +18,11 @@ def guess_encoding(fp):
 
     return default_encoding
 
+
 def _run():
     global __file__
-    import os, site
+    import os
+    import site  # noqa: F401
     sys.frozen = 'macosx_plugin'
     base = os.environ['RESOURCEPATH']
 
@@ -25,7 +30,8 @@ def _run():
         argv0 = os.path.basename(os.environ['ARGVZERO'])
     else:
         argv0 = None
-    script = SCRIPT_MAP.get(argv0, DEFAULT_SCRIPT)
+
+    script = SCRIPT_MAP.get(argv0, DEFAULT_SCRIPT)   # noqa: F821
 
     __file__ = path = os.path.join(base, script)
     if sys.version_info[0] == 2:
@@ -38,4 +44,8 @@ def _run():
         with open(path, 'r', encoding=encoding) as fp:
             source = fp.read() + '\n'
 
+        BOM = b'\xef\xbb\xbf'.decode('utf-8')
+        if source.startswith(BOM):
+            source = source[1:]
+
     exec(compile(source, path, 'exec'), globals(), globals())
